@@ -2,6 +2,6 @@ from lightwood.encoder.categorical.onehot import OneHotEncoder
 from lightwood.encoder.categorical.binary import BinaryEncoder
 from lightwood.encoder.time_series.rnn import TimeSeriesEncoder
 from lightwood.encoder.array.array import ArrayEncoder
+from lightwood.encoder.identity.identity import IdentityEncoder
 
-
-__all__ = ['BinaryEncoder', 'OneHotEncoder', 'TimeSeriesEncoder', 'ArrayEncoder']
+__all__ = ['BinaryEncoder', 'OneHotEncoder', 'TimeSeriesEncoder', 'ArrayEncoder', 'IdentityEncoder']
