@@ -1,7 +1,7 @@
 from lightwood.encoder.categorical.onehot import OneHotEncoder
 from lightwood.encoder.categorical.autoencoder import CategoricalAutoEncoder
 from lightwood.encoder.time_series.rnn import TimeSeriesEncoder
-from lightwood.encoder.time_series.plain import TimeSeriesPlainEncoder
+from lightwood.encoder.array.array import ArrayEncoder
 
 
-__all__ = ['OneHotEncoder', 'CategoricalAutoEncoder', 'TimeSeriesEncoder', 'TimeSeriesPlainEncoder']
+__all__ = ['OneHotEncoder', 'CategoricalAutoEncoder', 'TimeSeriesEncoder', 'ArrayEncoder']
