@@ -1,12 +1,37 @@
 import importlib
 from typing import List, Union, Dict, Optional
-
 import numpy as np
 import pandas as pd
 from sklearn.metrics import r2_score, f1_score, mean_absolute_error
+from lightwood.helpers.numeric import is_nan_numeric
 
 
-from lightwood.encoder.time_series.helpers.common import get_group_matches
+def get_group_matches(data, combination):
+    """Given a grouped-by combination, return rows of the data that match belong to it. Params:
+    data: dict with data to filter and group-by columns info.
+    combination: tuple with values to filter by
+    return: indexes for rows to normalize, data to normalize
+    """
+    keys = data['group_info'].keys()  # which column does each combination value belong to
+
+    if isinstance(data['data'], pd.Series):
+        data['data'] = np.vstack(data['data'])
+    if isinstance(data['data'], np.ndarray) and len(data['data'].shape) < 2:
+        data['data'] = np.expand_dims(data['data'], axis=1)
+
+    if combination == '__default':
+        idxs = range(len(data['data']))
+        return [idxs, np.array(data['data'])[idxs, :]]  # return all data
+    else:
+        all_sets = []
+        for val, key in zip(combination, keys):
+            all_sets.append(set([i for i, elt in enumerate(data['group_info'][key]) if elt == val]))
+        if all_sets:
+            idxs = list(set.intersection(*all_sets))
+            return idxs, np.array(data['data'])[idxs, :]
+
+        else:
+            return [], np.array([])
 
 
 # ------------------------- #
@@ -175,3 +200,30 @@ def mase(trues, preds, scale_error, fh):
         agg += mean_absolute_error(true, pred)
 
     return (agg / fh) / scale_error
+
+
+def is_none(value):
+    """
+    We use pandas :(
+    Pandas has no way to guarantee "stability" for the type of a column, it choses to arbitrarily change it based on the values.
+    Pandas also change the values in the columns based on the types.
+    Lightwood relies on having ``None`` values for a cells that represent "missing" or "corrupt".
+    
+    When we assign ``None`` to a cell in a dataframe this might get turned to `nan` or other values, this function checks if a cell is ``None`` or any other values a pd.DataFrame might convert ``None`` to.
+
+    It also check some extra values (like ``''``) that pandas never converts ``None`` to (hopefully). But lightwood would still consider those values "None values", and this will allow for more generic use later.
+    """ # noqa
+    if value is None:
+        return True
+
+    if is_nan_numeric(value):
+        return True
+
+    if str(value) == '':
+        return True
+
+    if str(value) in ('None', 'nan', 'NaN', 'np.nan'):
+        return True
+
+    return False
+
