@@ -1,6 +1,7 @@
 import unittest
 import numpy as np
 import pandas as pd
+import time
 from typing import List
 
 from lightwood.api.types import ProblemDefinition
@@ -45,17 +46,29 @@ class TestTimeseries(unittest.TestCase):
 
         return train, test
 
+    def calculate_duration(self, predictor, train, time_aim_expected):
+
+        start = time.process_time()
+        predictor.learn(train)
+        time_aim_actual = (time.process_time() - start)
+        if((time_aim_expected * 5) < time_aim_actual):
+            error = 'time_aim is set to {} seconds, however learning took {}'.format(time_aim_expected, time_aim_actual)
+            raise ValueError(error)
+        assert (time_aim_expected * 5) >= time_aim_actual
+        return predictor
+
     def test_0_time_series_grouped_regression(self):
         """Test grouped numerical predictions, with anomalies and forecast horizon > 1 """
         data = pd.read_csv('tests/data/arrivals.csv')
         train, test = self.split_arrivals(data, grouped=True)
         target = 'Traffic'
+        time_aim_expected = 30
         order_by = 'T'
         nr_preds = 2
         window = 5
         pred = predictor_from_problem(train,
                                       ProblemDefinition.from_dict({'target': target,
-                                                                   'time_aim': 30,
+                                                                   'time_aim': time_aim_expected,
                                                                    'anomaly_detection': True,
                                                                    'timeseries_settings': {
                                                                        'use_previous_target': True,
@@ -65,7 +78,7 @@ class TestTimeseries(unittest.TestCase):
                                                                        'order_by': [order_by],
                                                                        'window': window
                                                                    }}))
-        pred.learn(train)
+        pred = self.calculate_duration(pred, train, time_aim_expected)
         preds = pred.predict(test)
         self.check_ts_prediction_df(preds, nr_preds, [order_by])
 
@@ -125,6 +138,7 @@ class TestTimeseries(unittest.TestCase):
 
         df = pd.read_csv('tests/data/arrivals.csv')
         target = 'Traffic'
+        time_aim_expected = 30
         df[target] = df[target] > 100000
 
         train_idxs = np.random.rand(len(df)) < 0.8
@@ -133,7 +147,7 @@ class TestTimeseries(unittest.TestCase):
 
         predictor = predictor_from_problem(df,
                                            ProblemDefinition.from_dict({'target': target,
-                                                                        'time_aim': 30,
+                                                                        'time_aim': time_aim_expected,
                                                                         'anomaly_detection': False,
                                                                         'timeseries_settings': {
                                                                             'order_by': ['T'],
@@ -142,5 +156,58 @@ class TestTimeseries(unittest.TestCase):
                                                                         },
                                                                         }))
 
-        predictor.learn(train)
+        predictor = self.calculate_duration(predictor, train, time_aim_expected)
         predictor.predict(test)
+
+    def test_3_time_series_sktime_mixer(self):
+        """
+        Tests `sktime` mixer individually, as it has a special notion of absolute
+        temporal timestamps that we need to ensure are being used correctly. In
+        particular, given a train-dev-test split, any forecasts coming from a sktime
+        mixer should start from the latest observed data in the entire dataset.
+        """  # noqa
+
+        from sklearn.metrics import r2_score
+        from scipy import signal
+        from lightwood.api.high_level import (
+            ProblemDefinition,
+            json_ai_from_problem,
+            code_from_json_ai,
+            predictor_from_code,
+        )
+
+        # synth square wave
+        tsteps = 100
+        target = 'Value'
+        t = np.linspace(0, 1, tsteps, endpoint=False)
+        ts = signal.sawtooth(2 * np.pi * 5 * t, width=0.5)
+        df = pd.DataFrame(columns=['Time', target])
+        df['Time'] = t
+        df[target] = ts
+
+        train = df[:int(len(df) * 0.8)]
+        test = df[int(len(df) * 0.8):]
+
+        pdef = ProblemDefinition.from_dict({'target': target,
+                                            'time_aim': 10,
+                                            'timeseries_settings': {
+                                                'order_by': ['Time'],
+                                                'window': 5,
+                                                'nr_predictions': 20
+                                            }})
+
+        json_ai = json_ai_from_problem(df, problem_definition=pdef)
+        json_ai.outputs[target].mixers = [{
+            "module": "SkTime",
+            "args": {
+                "stop_after": "$problem_definition.seconds_per_mixer",
+                "n_ts_predictions": "$problem_definition.timeseries_settings.nr_predictions",
+            }}]
+
+        code = code_from_json_ai(json_ai)
+        predictor = predictor_from_code(code)
+
+        predictor.learn(train)
+        ps = predictor.predict(test)
+
+        assert r2_score(ps['truth'].values, ps['prediction'].iloc[0]) >= 0.95
